Perseus UI Plugin for CapiTainS Nemo
====================================

.. image:: https://badge.fury.io/py/perseus_nemo_ui.svg
    :target: https://badge.fury.io/py/perseus_nemo_ui

This repository contains templates, xslt and css for the Perseus instance of Nemo

It overrides the following templates:
    * menu
    * passage_footer
    
It adds the following to the nemo.secondary assets:
    * css
    * images
    * static/xslt

Contributors
############

- Bridget Almas ( @balmas )
- Thibault Clérice ( @ponteineptique )
